Coverage for /media/ldata/code/tendril/tendril/frontend/app.py: 0%

# Coverage for /media/ldata/code/tendril/tendril/frontend/app.py : 0%

## 5 statements 0 run 5 missing 0 excluded

Hot-keys on this page

r m x p toggle line displays

j k next/prev highlighted chunk

0 (zero) top of page

1 (one) first highlighted chunk

1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 | # Copyright (C) 2015 Chintalagiri Shashank # # This file is part of Tendril. # # This program is free software: you can redistribute it and/or modify # it under the terms of the GNU Affero General Public License as published by # the Free Software Foundation, either version 3 of the License, or # (at your option) any later version. # # This program is distributed in the hope that it will be useful, # but WITHOUT ANY WARRANTY; without even the implied warranty of # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the # GNU Affero General Public License for more details. # # You should have received a copy of the GNU Affero General Public License # along with this program. If not, see <http://www.gnu.org/licenses/>. """ This file is part of tendril See the COPYING, README, and INSTALL files for more information """ from flask import Flask from flask_sqlalchemy import SQLAlchemy # This is the WSGI compliant web application object app = Flask(__name__) # This is an SQLAlchemy ORM object. # # For the moment it points to a separate DB holding only app specific # information, i.e., access control mechanisms only. The fundamental # difference between this db instance and the one provided by utils.db # is that this relies on Flask-SQLAlchemy provided db.Model and it's # session management. The app should filter and do whatever it needs # to based on the app DB and then pass whatever information is necessary # to the underlying core via traditional function calls. # # This should be revisited at some point to reintegrate the DBs, either # by switching to the correct Base within the Flask-SQLAlchemy (and # sorting out the consequences to session management, as well as ensuring # that the Base is compatible with what Flask plugins expect), or # rewriting the Flask plugins to work with the vanilla Base. db = SQLAlchemy(app)